@@ -20,7 +20,7 @@
 
 template <typename eT>
 inline SpSubview<eT>::~SpSubview() {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 }
 
 template <typename eT>
@@ -34,21 +34,28 @@ inline SpSubview<eT>::SpSubview(const SpMat<eT>& in_m, const uword in_row1,
       n_cols(in_n_cols),
       n_elem(in_n_rows * in_n_cols),
       n_nonzero(0) {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
 
   m.sync_csc();
 
-  // There must be a O(1) way to do this
-  uword lend = m.col_ptrs[in_col1 + in_n_cols];
-  uword lend_row = in_row1 + in_n_rows;
+  // count the number of non-zeros in the subview
   uword count = 0;
 
-  for (uword i = m.col_ptrs[in_col1]; i < lend; ++i) {
-    const uword m_row_indices_i = m.row_indices[i];
+  if (n_rows == m.n_rows) {
+    count = m.col_ptrs[aux_col1 + n_cols] - m.col_ptrs[aux_col1];
+  } else {
+    arma_debug_print("counting non-zeros in sparse subview");
 
-    const bool condition = (m_row_indices_i >= in_row1) && (m_row_indices_i < lend_row);
+    uword lend = m.col_ptrs[in_col1 + in_n_cols];
+    uword lend_row = in_row1 + in_n_rows;
 
-    count += condition ? uword(1) : uword(0);
+    for (uword i = m.col_ptrs[in_col1]; i < lend; ++i) {
+      const uword m_row_indices_i = m.row_indices[i];
+
+      const bool condition = (m_row_indices_i >= in_row1) && (m_row_indices_i < lend_row);
+
+      count += condition ? uword(1) : uword(0);
+    }
   }
 
   access::rw(n_nonzero) = count;
@@ -63,7 +70,7 @@ inline SpSubview<eT>::SpSubview(const SpSubview<eT>& in)
       n_cols(in.n_cols),
       n_elem(in.n_elem),
       n_nonzero(in.n_nonzero) {
-  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  arma_debug_sigprint(arma_str::format("this: %x; in: %x") % this % &in);
 }
 
 template <typename eT>
@@ -75,7 +82,7 @@ inline SpSubview<eT>::SpSubview(SpSubview<eT>&& in)
       n_cols(in.n_cols),
       n_elem(in.n_elem),
       n_nonzero(in.n_nonzero) {
-  arma_extra_debug_sigprint(arma_str::format("this = %x   in = %x") % this % &in);
+  arma_debug_sigprint(arma_str::format("this: %x; in: %x") % this % &in);
 
   // for paranoia
 
@@ -89,7 +96,7 @@ inline SpSubview<eT>::SpSubview(SpSubview<eT>&& in)
 
 template <typename eT>
 inline const SpSubview<eT>& SpSubview<eT>::operator+=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     return *this;
@@ -104,7 +111,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator+=(const eT val) {
 
 template <typename eT>
 inline const SpSubview<eT>& SpSubview<eT>::operator-=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     return *this;
@@ -119,7 +126,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator-=(const eT val) {
 
 template <typename eT>
 inline const SpSubview<eT>& SpSubview<eT>::operator*=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     (*this).zeros();
@@ -178,9 +185,9 @@ inline const SpSubview<eT>& SpSubview<eT>::operator*=(const eT val) {
 
 template <typename eT>
 inline const SpSubview<eT>& SpSubview<eT>::operator/=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((val == eT(0)), "element-wise division: division by zero");
+  arma_conform_check((val == eT(0)), "element-wise division: division by zero");
 
   m.sync_csc();
   m.invalidate_cache();
@@ -231,13 +238,13 @@ inline const SpSubview<eT>& SpSubview<eT>::operator/=(const eT val) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator=(const Base<eT, T1>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (is_same_type<T1, Gen<Mat<eT>, gen_zeros> >::yes) {
     const Proxy<T1> P(in.get_ref());
 
-    arma_debug_assert_same_size(n_rows, n_cols, P.get_n_rows(), P.get_n_cols(),
-                                "insertion into sparse submatrix");
+    arma_conform_assert_same_size(n_rows, n_cols, P.get_n_rows(), P.get_n_cols(),
+                                  "insertion into sparse submatrix");
 
     (*this).zeros();
 
@@ -247,8 +254,8 @@ inline const SpSubview<eT>& SpSubview<eT>::operator=(const Base<eT, T1>& in) {
   if (is_same_type<T1, Gen<Mat<eT>, gen_eye> >::yes) {
     const Proxy<T1> P(in.get_ref());
 
-    arma_debug_assert_same_size(n_rows, n_cols, P.get_n_rows(), P.get_n_cols(),
-                                "insertion into sparse submatrix");
+    arma_conform_assert_same_size(n_rows, n_cols, P.get_n_rows(), P.get_n_cols(),
+                                  "insertion into sparse submatrix");
 
     (*this).eye();
 
@@ -257,8 +264,8 @@ inline const SpSubview<eT>& SpSubview<eT>::operator=(const Base<eT, T1>& in) {
 
   const quasi_unwrap<T1> U(in.get_ref());
 
-  arma_debug_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols,
-                              "insertion into sparse submatrix");
+  arma_conform_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols,
+                                "insertion into sparse submatrix");
 
   spglue_merge::subview_merge(*this, U.M);
 
@@ -268,7 +275,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator=(const Base<eT, T1>& in) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator+=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return (*this).operator=((*this) + x.get_ref());
 }
@@ -276,7 +283,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator+=(const Base<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator-=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return (*this).operator=((*this) - x.get_ref());
 }
@@ -284,7 +291,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator-=(const Base<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator*=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT> tmp(*this);
 
@@ -296,15 +303,15 @@ inline const SpSubview<eT>& SpSubview<eT>::operator*=(const Base<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator%=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>& sv = (*this);
 
   const quasi_unwrap<T1> U(x.get_ref());
   const Mat<eT>& B = U.M;
 
-  arma_debug_assert_same_size(sv.n_rows, sv.n_cols, B.n_rows, B.n_cols,
-                              "element-wise multiplication");
+  arma_conform_assert_same_size(sv.n_rows, sv.n_cols, B.n_rows, B.n_cols,
+                                "element-wise multiplication");
 
   SpMat<eT>& sv_m = access::rw(sv.m);
 
@@ -366,15 +373,15 @@ inline const SpSubview<eT>& SpSubview<eT>::operator%=(const Base<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator/=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const SpSubview<eT>& A = (*this);
 
   const quasi_unwrap<T1> U(x.get_ref());
   const Mat<eT>& B = U.M;
 
-  arma_debug_assert_same_size(A.n_rows, A.n_cols, B.n_rows, B.n_cols,
-                              "element-wise division");
+  arma_conform_assert_same_size(A.n_rows, A.n_cols, B.n_rows, B.n_cols,
+                                "element-wise division");
 
   bool result_ok = true;
 
@@ -436,7 +443,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator/=(const Base<eT, T1>& x) {
 
 template <typename eT>
 inline const SpSubview<eT>& SpSubview<eT>::operator=(const SpSubview<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return (*this).operator_equ_common(x);
 }
@@ -444,7 +451,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator=(const SpSubview<eT>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return (*this).operator_equ_common(x.get_ref());
 }
@@ -452,12 +459,12 @@ inline const SpSubview<eT>& SpSubview<eT>::operator=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator_equ_common(const SpBase<eT, T1>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap_spmat<T1> U(in.get_ref());
 
-  arma_debug_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols,
-                              "insertion into sparse submatrix");
+  arma_conform_assert_same_size(n_rows, n_cols, U.M.n_rows, U.M.n_cols,
+                                "insertion into sparse submatrix");
 
   if (U.is_alias(m)) {
     const SpMat<eT> tmp(U.M);
@@ -473,7 +480,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator_equ_common(const SpBase<eT,
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator+=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // TODO: implement dedicated machinery
   return (*this).operator=((*this) + x.get_ref());
@@ -482,7 +489,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator+=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator-=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // TODO: implement dedicated machinery
   return (*this).operator=((*this) - x.get_ref());
@@ -491,7 +498,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator-=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator*=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return (*this).operator=((*this) * x.get_ref());
 }
@@ -499,7 +506,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator*=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator%=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // TODO: implement dedicated machinery
   return (*this).operator=((*this) % x.get_ref());
@@ -508,14 +515,14 @@ inline const SpSubview<eT>& SpSubview<eT>::operator%=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline const SpSubview<eT>& SpSubview<eT>::operator/=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // NOTE: use of this function is not advised; it is implemented only for completeness
 
   SpProxy<T1> p(x.get_ref());
 
-  arma_debug_assert_same_size(n_rows, n_cols, p.get_n_rows(), p.get_n_cols(),
-                              "element-wise division");
+  arma_conform_assert_same_size(n_rows, n_cols, p.get_n_rows(), p.get_n_cols(),
+                                "element-wise division");
 
   if (p.is_alias(m) == false) {
     for (uword lcol = 0; lcol < n_cols; ++lcol)
@@ -535,7 +542,7 @@ inline const SpSubview<eT>& SpSubview<eT>::operator/=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename functor>
 inline void SpSubview<eT>::for_each(functor F) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   m.sync_csc();
   m.invalidate_cache();
@@ -584,7 +591,7 @@ inline void SpSubview<eT>::for_each(functor F) {
 template <typename eT>
 template <typename functor>
 inline void SpSubview<eT>::for_each(functor F) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   m.sync_csc();
 
@@ -614,7 +621,7 @@ inline void SpSubview<eT>::for_each(functor F) const {
 template <typename eT>
 template <typename functor>
 inline void SpSubview<eT>::transform(functor F) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   m.sync_csc();
   m.invalidate_cache();
@@ -662,7 +669,7 @@ inline void SpSubview<eT>::transform(functor F) {
 
 template <typename eT>
 inline void SpSubview<eT>::replace(const eT old_val, const eT new_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (old_val == eT(0)) {
     if (new_val != eT(0)) {
@@ -727,7 +734,7 @@ inline void SpSubview<eT>::replace(const eT old_val, const eT new_val) {
 
 template <typename eT>
 inline void SpSubview<eT>::clean(const typename get_pod_type<eT>::result threshold) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if ((n_elem == 0) || (n_nonzero == 0)) {
     return;
@@ -748,16 +755,18 @@ inline void SpSubview<eT>::clean(const typename get_pod_type<eT>::result thresho
 
 template <typename eT>
 inline void SpSubview<eT>::clamp(const eT min_val, const eT max_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (is_cx<eT>::no) {
-    arma_debug_check((access::tmp_real(min_val) > access::tmp_real(max_val)),
-                     "SpSubview::clamp(): min_val must be less than max_val");
+    arma_conform_check((access::tmp_real(min_val) > access::tmp_real(max_val)),
+                       "SpSubview::clamp(): min_val must be less than max_val");
   } else {
-    arma_debug_check((access::tmp_real(min_val) > access::tmp_real(max_val)),
-                     "SpSubview::clamp(): real(min_val) must be less than real(max_val)");
-    arma_debug_check((access::tmp_imag(min_val) > access::tmp_imag(max_val)),
-                     "SpSubview::clamp(): imag(min_val) must be less than imag(max_val)");
+    arma_conform_check(
+        (access::tmp_real(min_val) > access::tmp_real(max_val)),
+        "SpSubview::clamp(): real(min_val) must be less than real(max_val)");
+    arma_conform_check(
+        (access::tmp_imag(min_val) > access::tmp_imag(max_val)),
+        "SpSubview::clamp(): imag(min_val) must be less than imag(max_val)");
   }
 
   if ((n_elem == 0) || (n_nonzero == 0)) {
@@ -775,7 +784,7 @@ inline void SpSubview<eT>::clamp(const eT min_val, const eT max_val) {
 
 template <typename eT>
 inline void SpSubview<eT>::fill(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val != eT(0)) {
     Mat<eT> tmp((*this).n_rows, (*this).n_cols, arma_nozeros_indicator());
@@ -790,7 +799,7 @@ inline void SpSubview<eT>::fill(const eT val) {
 
 template <typename eT>
 inline void SpSubview<eT>::zeros() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if ((n_elem == 0) || (n_nonzero == 0)) {
     return;
@@ -841,14 +850,14 @@ inline void SpSubview<eT>::zeros() {
 
 template <typename eT>
 inline void SpSubview<eT>::ones() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   (*this).fill(eT(1));
 }
 
 template <typename eT>
 inline void SpSubview<eT>::eye() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT> tmp;
 
@@ -859,7 +868,7 @@ inline void SpSubview<eT>::eye() {
 
 template <typename eT>
 inline void SpSubview<eT>::randu() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp((*this).n_rows, (*this).n_cols, fill::randu);
 
@@ -868,7 +877,7 @@ inline void SpSubview<eT>::randu() {
 
 template <typename eT>
 inline void SpSubview<eT>::randn() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp((*this).n_rows, (*this).n_cols, fill::randn);
 
@@ -893,7 +902,7 @@ inline eT SpSubview<eT>::operator[](const uword i) const {
 
 template <typename eT>
 inline SpSubview_MapMat_val<eT> SpSubview<eT>::operator()(const uword i) {
-  arma_debug_check_bounds((i >= n_elem), "SpSubview::operator(): index out of bounds");
+  arma_conform_check_bounds((i >= n_elem), "SpSubview::operator(): index out of bounds");
 
   const uword lrow = i % n_rows;
   const uword lcol = i / n_rows;
@@ -903,7 +912,7 @@ inline SpSubview_MapMat_val<eT> SpSubview<eT>::operator()(const uword i) {
 
 template <typename eT>
 inline eT SpSubview<eT>::operator()(const uword i) const {
-  arma_debug_check_bounds((i >= n_elem), "SpSubview::operator(): index out of bounds");
+  arma_conform_check_bounds((i >= n_elem), "SpSubview::operator(): index out of bounds");
 
   const uword lrow = i % n_rows;
   const uword lcol = i / n_rows;
@@ -914,16 +923,16 @@ inline eT SpSubview<eT>::operator()(const uword i) const {
 template <typename eT>
 inline SpSubview_MapMat_val<eT> SpSubview<eT>::operator()(const uword in_row,
                                                           const uword in_col) {
-  arma_debug_check_bounds((in_row >= n_rows) || (in_col >= n_cols),
-                          "SpSubview::operator(): index out of bounds");
+  arma_conform_check_bounds((in_row >= n_rows) || (in_col >= n_cols),
+                            "SpSubview::operator(): index out of bounds");
 
   return (*this).at(in_row, in_col);
 }
 
 template <typename eT>
 inline eT SpSubview<eT>::operator()(const uword in_row, const uword in_col) const {
-  arma_debug_check_bounds((in_row >= n_rows) || (in_col >= n_cols),
-                          "SpSubview::operator(): index out of bounds");
+  arma_conform_check_bounds((in_row >= n_rows) || (in_col >= n_cols),
+                            "SpSubview::operator(): index out of bounds");
 
   return (*this).at(in_row, in_col);
 }
@@ -994,9 +1003,9 @@ inline bool SpSubview<eT>::is_vec() const {
 
 template <typename eT>
 inline SpSubview_row<eT> SpSubview<eT>::row(const uword row_num) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(row_num >= n_rows, "SpSubview::row(): out of bounds");
+  arma_conform_check_bounds(row_num >= n_rows, "SpSubview::row(): out of bounds");
 
   return SpSubview_row<eT>(const_cast<SpMat<eT>&>(m), row_num + aux_row1, aux_col1,
                            n_cols);
@@ -1004,18 +1013,18 @@ inline SpSubview_row<eT> SpSubview<eT>::row(const uword row_num) {
 
 template <typename eT>
 inline const SpSubview_row<eT> SpSubview<eT>::row(const uword row_num) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(row_num >= n_rows, "SpSubview::row(): out of bounds");
+  arma_conform_check_bounds(row_num >= n_rows, "SpSubview::row(): out of bounds");
 
   return SpSubview_row<eT>(m, row_num + aux_row1, aux_col1, n_cols);
 }
 
 template <typename eT>
 inline SpSubview_col<eT> SpSubview<eT>::col(const uword col_num) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(col_num >= n_cols, "SpSubview::col(): out of bounds");
+  arma_conform_check_bounds(col_num >= n_cols, "SpSubview::col(): out of bounds");
 
   return SpSubview_col<eT>(const_cast<SpMat<eT>&>(m), col_num + aux_col1, aux_row1,
                            n_rows);
@@ -1023,19 +1032,20 @@ inline SpSubview_col<eT> SpSubview<eT>::col(const uword col_num) {
 
 template <typename eT>
 inline const SpSubview_col<eT> SpSubview<eT>::col(const uword col_num) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(col_num >= n_cols, "SpSubview::col(): out of bounds");
+  arma_conform_check_bounds(col_num >= n_cols, "SpSubview::col(): out of bounds");
 
   return SpSubview_col<eT>(m, col_num + aux_col1, aux_row1, n_rows);
 }
 
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::rows(const uword in_row1, const uword in_row2) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds((in_row1 > in_row2) || (in_row2 >= n_rows),
-                          "SpSubview::rows(): indices out of bounds or incorrectly used");
+  arma_conform_check_bounds(
+      (in_row1 > in_row2) || (in_row2 >= n_rows),
+      "SpSubview::rows(): indices out of bounds or incorrectly used");
 
   return submat(in_row1, 0, in_row2, n_cols - 1);
 }
@@ -1043,20 +1053,22 @@ inline SpSubview<eT> SpSubview<eT>::rows(const uword in_row1, const uword in_row
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::rows(const uword in_row1,
                                                const uword in_row2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds((in_row1 > in_row2) || (in_row2 >= n_rows),
-                          "SpSubview::rows(): indices out of bounds or incorrectly used");
+  arma_conform_check_bounds(
+      (in_row1 > in_row2) || (in_row2 >= n_rows),
+      "SpSubview::rows(): indices out of bounds or incorrectly used");
 
   return submat(in_row1, 0, in_row2, n_cols - 1);
 }
 
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::cols(const uword in_col1, const uword in_col2) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds((in_col1 > in_col2) || (in_col2 >= n_cols),
-                          "SpSubview::cols(): indices out of bounds or incorrectly used");
+  arma_conform_check_bounds(
+      (in_col1 > in_col2) || (in_col2 >= n_cols),
+      "SpSubview::cols(): indices out of bounds or incorrectly used");
 
   return submat(0, in_col1, n_rows - 1, in_col2);
 }
@@ -1064,10 +1076,11 @@ inline SpSubview<eT> SpSubview<eT>::cols(const uword in_col1, const uword in_col
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::cols(const uword in_col1,
                                                const uword in_col2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds((in_col1 > in_col2) || (in_col2 >= n_cols),
-                          "SpSubview::cols(): indices out of bounds or incorrectly used");
+  arma_conform_check_bounds(
+      (in_col1 > in_col2) || (in_col2 >= n_cols),
+      "SpSubview::cols(): indices out of bounds or incorrectly used");
 
   return submat(0, in_col1, n_rows - 1, in_col2);
 }
@@ -1075,9 +1088,9 @@ inline const SpSubview<eT> SpSubview<eT>::cols(const uword in_col1,
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::submat(const uword in_row1, const uword in_col1,
                                            const uword in_row2, const uword in_col2) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(
+  arma_conform_check_bounds(
       (in_row1 > in_row2) || (in_col1 > in_col2) || (in_row2 >= n_rows) ||
           (in_col2 >= n_cols),
       "SpSubview::submat(): indices out of bounds or incorrectly used");
@@ -1090,9 +1103,9 @@ template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::submat(const uword in_row1, const uword in_col1,
                                                  const uword in_row2,
                                                  const uword in_col2) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check_bounds(
+  arma_conform_check_bounds(
       (in_row1 > in_row2) || (in_col1 > in_col2) || (in_row2 >= n_rows) ||
           (in_col2 >= n_cols),
       "SpSubview::submat(): indices out of bounds or incorrectly used");
@@ -1103,7 +1116,7 @@ inline const SpSubview<eT> SpSubview<eT>::submat(const uword in_row1, const uwor
 
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::submat(const span& row_span, const span& col_span) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool row_all = row_span.whole;
   const bool col_all = row_span.whole;
@@ -1114,7 +1127,7 @@ inline SpSubview<eT> SpSubview<eT>::submat(const span& row_span, const span& col
   const uword in_col1 = col_all ? 0 : col_span.a;
   const uword in_col2 = col_all ? n_cols : col_span.b;
 
-  arma_debug_check_bounds(
+  arma_conform_check_bounds(
       (row_all ? false : ((in_row1 > in_row2) || (in_row2 >= n_rows))) ||
           (col_all ? false : ((in_col1 > in_col2) || (in_col2 >= n_cols))),
       "SpSubview::submat(): indices out of bounds or incorrectly used");
@@ -1125,7 +1138,7 @@ inline SpSubview<eT> SpSubview<eT>::submat(const span& row_span, const span& col
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::submat(const span& row_span,
                                                  const span& col_span) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const bool row_all = row_span.whole;
   const bool col_all = row_span.whole;
@@ -1136,7 +1149,7 @@ inline const SpSubview<eT> SpSubview<eT>::submat(const span& row_span,
   const uword in_col1 = col_all ? 0 : col_span.a;
   const uword in_col2 = col_all ? n_cols - 1 : col_span.b;
 
-  arma_debug_check_bounds(
+  arma_conform_check_bounds(
       (row_all ? false : ((in_row1 > in_row2) || (in_row2 >= n_rows))) ||
           (col_all ? false : ((in_col1 > in_col2) || (in_col2 >= n_cols))),
       "SpSubview::submat(): indices out of bounds or incorrectly used");
@@ -1147,7 +1160,7 @@ inline const SpSubview<eT> SpSubview<eT>::submat(const span& row_span,
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::operator()(const uword row_num,
                                                const span& col_span) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(span(row_num, row_num), col_span);
 }
@@ -1155,7 +1168,7 @@ inline SpSubview<eT> SpSubview<eT>::operator()(const uword row_num,
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::operator()(const uword row_num,
                                                      const span& col_span) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(span(row_num, row_num), col_span);
 }
@@ -1163,7 +1176,7 @@ inline const SpSubview<eT> SpSubview<eT>::operator()(const uword row_num,
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
                                                const uword col_num) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(row_span, span(col_num, col_num));
 }
@@ -1171,7 +1184,7 @@ inline SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
                                                      const uword col_num) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(row_span, span(col_num, col_num));
 }
@@ -1179,7 +1192,7 @@ inline const SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
 template <typename eT>
 inline SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
                                                const span& col_span) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(row_span, col_span);
 }
@@ -1187,17 +1200,17 @@ inline SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
 template <typename eT>
 inline const SpSubview<eT> SpSubview<eT>::operator()(const span& row_span,
                                                      const span& col_span) const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   return submat(row_span, col_span);
 }
 
 template <typename eT>
 inline void SpSubview<eT>::swap_rows(const uword in_row1, const uword in_row2) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((in_row1 >= n_rows) || (in_row2 >= n_rows),
-                   "SpSubview::swap_rows(): invalid row index");
+  arma_conform_check((in_row1 >= n_rows) || (in_row2 >= n_rows),
+                     "SpSubview::swap_rows(): invalid row index");
 
   const uword lstart_col = aux_col1;
   const uword lend_col = aux_col1 + n_cols;
@@ -1211,10 +1224,10 @@ inline void SpSubview<eT>::swap_rows(const uword in_row1, const uword in_row2) {
 
 template <typename eT>
 inline void SpSubview<eT>::swap_cols(const uword in_col1, const uword in_col2) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
-  arma_debug_check((in_col1 >= n_cols) || (in_col2 >= n_cols),
-                   "SpSubview::swap_cols(): invalid column index");
+  arma_conform_check((in_col1 >= n_cols) || (in_col2 >= n_cols),
+                     "SpSubview::swap_cols(): invalid column index");
 
   const uword lstart_row = aux_row1;
   const uword lend_row = aux_row1 + n_rows;
@@ -1336,7 +1349,7 @@ arma_inline bool SpSubview<eT>::is_alias(const SpMat<eT>& X) const {
 template <typename eT>
 inline eT& SpSubview<eT>::insert_element(const uword in_row, const uword in_col,
                                          const eT in_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // This may not actually insert an element.
   const uword old_n_nonzero = m.n_nonzero;
@@ -1349,7 +1362,7 @@ inline eT& SpSubview<eT>::insert_element(const uword in_row, const uword in_col,
 
 template <typename eT>
 inline void SpSubview<eT>::delete_element(const uword in_row, const uword in_col) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // This may not actually delete an element.
   const uword old_n_nonzero = m.n_nonzero;
@@ -1359,7 +1372,7 @@ inline void SpSubview<eT>::delete_element(const uword in_row, const uword in_col
 
 template <typename eT>
 inline void SpSubview<eT>::invalidate_cache() const {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   m.invalidate_cache();
 }
@@ -1371,26 +1384,26 @@ inline void SpSubview<eT>::invalidate_cache() const {
 template <typename eT>
 inline SpSubview_col<eT>::SpSubview_col(const SpMat<eT>& in_m, const uword in_col)
     : SpSubview<eT>(in_m, 0, in_col, in_m.n_rows, 1) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 template <typename eT>
 inline SpSubview_col<eT>::SpSubview_col(const SpMat<eT>& in_m, const uword in_col,
                                         const uword in_row1, const uword in_n_rows)
     : SpSubview<eT>(in_m, in_row1, in_col, in_n_rows, 1) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 template <typename eT>
 inline void SpSubview_col<eT>::operator=(const SpSubview<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
 
 template <typename eT>
 inline void SpSubview_col<eT>::operator=(const SpSubview_col<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);  // interprets 'SpSubview_col' as 'SpSubview'
 }
@@ -1398,7 +1411,7 @@ inline void SpSubview_col<eT>::operator=(const SpSubview_col<eT>& x) {
 template <typename eT>
 template <typename T1>
 inline void SpSubview_col<eT>::operator=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
@@ -1406,7 +1419,7 @@ inline void SpSubview_col<eT>::operator=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline void SpSubview_col<eT>::operator=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
@@ -1426,6 +1439,12 @@ inline const SpOp<SpSubview_col<eT>, spop_strans> SpSubview_col<eT>::st() const
   return SpOp<SpSubview_col<eT>, spop_strans>(*this);
 }
 
+template <typename eT>
+inline const SpToDOp<SpSubview_col<eT>, op_sp_as_dense> SpSubview_col<eT>::as_dense()
+    const {
+  return SpToDOp<SpSubview_col<eT>, op_sp_as_dense>(*this);
+}
+
 //
 //
 //
@@ -1433,26 +1452,26 @@ inline const SpOp<SpSubview_col<eT>, spop_strans> SpSubview_col<eT>::st() const
 template <typename eT>
 inline SpSubview_row<eT>::SpSubview_row(const SpMat<eT>& in_m, const uword in_row)
     : SpSubview<eT>(in_m, in_row, 0, 1, in_m.n_cols) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 template <typename eT>
 inline SpSubview_row<eT>::SpSubview_row(const SpMat<eT>& in_m, const uword in_row,
                                         const uword in_col1, const uword in_n_cols)
     : SpSubview<eT>(in_m, in_row, in_col1, 1, in_n_cols) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 template <typename eT>
 inline void SpSubview_row<eT>::operator=(const SpSubview<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
 
 template <typename eT>
 inline void SpSubview_row<eT>::operator=(const SpSubview_row<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);  // interprets 'SpSubview_row' as 'SpSubview'
 }
@@ -1460,7 +1479,7 @@ inline void SpSubview_row<eT>::operator=(const SpSubview_row<eT>& x) {
 template <typename eT>
 template <typename T1>
 inline void SpSubview_row<eT>::operator=(const SpBase<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
@@ -1468,7 +1487,7 @@ inline void SpSubview_row<eT>::operator=(const SpBase<eT, T1>& x) {
 template <typename eT>
 template <typename T1>
 inline void SpSubview_row<eT>::operator=(const Base<eT, T1>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpSubview<eT>::operator=(x);
 }
@@ -1488,4 +1507,10 @@ inline const SpOp<SpSubview_row<eT>, spop_strans> SpSubview_row<eT>::st() const
   return SpOp<SpSubview_row<eT>, spop_strans>(*this);
 }
 
+template <typename eT>
+inline const SpToDOp<SpSubview_row<eT>, op_sp_as_dense> SpSubview_row<eT>::as_dense()
+    const {
+  return SpToDOp<SpSubview_row<eT>, op_sp_as_dense>(*this);
+}
+
 //! @}
