@@ -20,7 +20,7 @@
 
 template <typename eT>
 inline spdiagview<eT>::~spdiagview() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 template <typename eT>
@@ -31,18 +31,18 @@ arma_inline spdiagview<eT>::spdiagview(const SpMat<eT>& in_m, const uword in_row
       col_offset(in_col_offset),
       n_rows(in_len),
       n_elem(in_len) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 }
 
 //! set a diagonal of our matrix using a diagonal from a foreign matrix
 template <typename eT>
 inline void spdiagview<eT>::operator=(const spdiagview<eT>& x) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
-  arma_debug_check((d.n_elem != x.n_elem),
-                   "spdiagview: diagonals have incompatible lengths");
+  arma_conform_check((d.n_elem != x.n_elem),
+                     "spdiagview: diagonals have incompatible lengths");
 
   SpMat<eT>& d_m = const_cast<SpMat<eT>&>(d.m);
   const SpMat<eT>& x_m = x.m;
@@ -68,7 +68,7 @@ inline void spdiagview<eT>::operator=(const spdiagview<eT>& x) {
 
 template <typename eT>
 inline void spdiagview<eT>::operator+=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     return;
@@ -87,7 +87,7 @@ inline void spdiagview<eT>::operator+=(const eT val) {
 
 template <typename eT>
 inline void spdiagview<eT>::operator-=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     return;
@@ -106,7 +106,7 @@ inline void spdiagview<eT>::operator-=(const eT val) {
 
 template <typename eT>
 inline void spdiagview<eT>::operator*=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (val == eT(0)) {
     (*this).zeros();
@@ -126,7 +126,7 @@ inline void spdiagview<eT>::operator*=(const eT val) {
 
 template <typename eT>
 inline void spdiagview<eT>::operator/=(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT>& t_m = const_cast<SpMat<eT>&>(m);
 
@@ -143,7 +143,7 @@ inline void spdiagview<eT>::operator/=(const eT val) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -156,8 +156,8 @@ inline void spdiagview<eT>::operator=(const Base<eT, T1>& o) {
   if (is_same_type<T1, Gen<Col<eT>, gen_zeros> >::yes) {
     const Proxy<T1> P(o.get_ref());
 
-    arma_debug_check((d_n_elem != P.get_n_elem()),
-                     "spdiagview: given object has incompatible size");
+    arma_conform_check((d_n_elem != P.get_n_elem()),
+                       "spdiagview: given object has incompatible size");
 
     (*this).zeros();
 
@@ -167,8 +167,8 @@ inline void spdiagview<eT>::operator=(const Base<eT, T1>& o) {
   if (is_same_type<T1, Gen<Col<eT>, gen_ones> >::yes) {
     const Proxy<T1> P(o.get_ref());
 
-    arma_debug_check((d_n_elem != P.get_n_elem()),
-                     "spdiagview: given object has incompatible size");
+    arma_conform_check((d_n_elem != P.get_n_elem()),
+                       "spdiagview: given object has incompatible size");
 
     (*this).ones();
 
@@ -180,8 +180,8 @@ inline void spdiagview<eT>::operator=(const Base<eT, T1>& o) {
 
   const eT* x_mem = x.memptr();
 
-  arma_debug_check(((d_n_elem != x.n_elem) || ((x.n_rows != 1) && (x.n_cols != 1))),
-                   "spdiagview: given object has incompatible size");
+  arma_conform_check(((d_n_elem != x.n_elem) || ((x.n_rows != 1) && (x.n_cols != 1))),
+                     "spdiagview: given object has incompatible size");
 
   if ((d_row_offset == 0) && (d_col_offset == 0)) {
     SpMat<eT> tmp1;
@@ -224,7 +224,7 @@ inline void spdiagview<eT>::operator=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator+=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -236,7 +236,7 @@ inline void spdiagview<eT>::operator+=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -261,7 +261,7 @@ inline void spdiagview<eT>::operator+=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator-=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -273,7 +273,7 @@ inline void spdiagview<eT>::operator-=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -298,7 +298,7 @@ inline void spdiagview<eT>::operator-=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator%=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -310,7 +310,7 @@ inline void spdiagview<eT>::operator%=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -335,7 +335,7 @@ inline void spdiagview<eT>::operator%=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator/=(const Base<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -347,7 +347,7 @@ inline void spdiagview<eT>::operator/=(const Base<eT, T1>& o) {
 
   const Proxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -373,13 +373,13 @@ inline void spdiagview<eT>::operator/=(const Base<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator=(const SpBase<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const unwrap_spmat<T1> U(o.get_ref());
   const SpMat<eT>& x = U.M;
 
-  arma_debug_check(((n_elem != x.n_elem) || ((x.n_rows != 1) && (x.n_cols != 1))),
-                   "spdiagview: given object has incompatible size");
+  arma_conform_check(((n_elem != x.n_elem) || ((x.n_rows != 1) && (x.n_cols != 1))),
+                     "spdiagview: given object has incompatible size");
 
   const Mat<eT> tmp(x);
 
@@ -389,7 +389,7 @@ inline void spdiagview<eT>::operator=(const SpBase<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator+=(const SpBase<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -401,7 +401,7 @@ inline void spdiagview<eT>::operator+=(const SpBase<eT, T1>& o) {
 
   const SpProxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -433,7 +433,7 @@ inline void spdiagview<eT>::operator+=(const SpBase<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator-=(const SpBase<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -445,7 +445,7 @@ inline void spdiagview<eT>::operator-=(const SpBase<eT, T1>& o) {
 
   const SpProxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -477,7 +477,7 @@ inline void spdiagview<eT>::operator-=(const SpBase<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator%=(const SpBase<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -489,7 +489,7 @@ inline void spdiagview<eT>::operator%=(const SpBase<eT, T1>& o) {
 
   const SpProxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -521,7 +521,7 @@ inline void spdiagview<eT>::operator%=(const SpBase<eT, T1>& o) {
 template <typename eT>
 template <typename T1>
 inline void spdiagview<eT>::operator/=(const SpBase<eT, T1>& o) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   spdiagview<eT>& d = *this;
 
@@ -533,7 +533,7 @@ inline void spdiagview<eT>::operator/=(const SpBase<eT, T1>& o) {
 
   const SpProxy<T1> P(o.get_ref());
 
-  arma_debug_check(
+  arma_conform_check(
       ((d_n_elem != P.get_n_elem()) || ((P.get_n_rows() != 1) && (P.get_n_cols() != 1))),
       "spdiagview: given object has incompatible size");
 
@@ -564,7 +564,7 @@ inline void spdiagview<eT>::operator/=(const SpBase<eT, T1>& o) {
 
 template <typename eT>
 inline void spdiagview<eT>::extract(SpMat<eT>& out, const spdiagview<eT>& d) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   const SpMat<eT>& d_m = d.m;
 
@@ -605,7 +605,7 @@ inline void spdiagview<eT>::extract(SpMat<eT>& out, const spdiagview<eT>& d) {
 //! extract a diagonal and store it as a dense column vector
 template <typename eT>
 inline void spdiagview<eT>::extract(Mat<eT>& out, const spdiagview<eT>& in) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   // NOTE: we're assuming that the 'out' matrix has already been set to the correct size;
   // size setting is done by either the Mat contructor or Mat::operator=()
@@ -645,14 +645,14 @@ inline eT spdiagview<eT>::at(const uword i) const {
 
 template <typename eT>
 inline SpMat_MapMat_val<eT> spdiagview<eT>::operator()(const uword i) {
-  arma_debug_check_bounds((i >= n_elem), "spdiagview::operator(): out of bounds");
+  arma_conform_check_bounds((i >= n_elem), "spdiagview::operator(): out of bounds");
 
   return (const_cast<SpMat<eT>&>(m)).at(i + row_offset, i + col_offset);
 }
 
 template <typename eT>
 inline eT spdiagview<eT>::operator()(const uword i) const {
-  arma_debug_check_bounds((i >= n_elem), "spdiagview::operator(): out of bounds");
+  arma_conform_check_bounds((i >= n_elem), "spdiagview::operator(): out of bounds");
 
   return m.at(i + row_offset, i + col_offset);
 }
@@ -669,27 +669,26 @@ inline eT spdiagview<eT>::at(const uword row, const uword) const {
 
 template <typename eT>
 inline SpMat_MapMat_val<eT> spdiagview<eT>::operator()(const uword row, const uword col) {
-  arma_debug_check_bounds(((row >= n_elem) || (col > 0)),
-                          "spdiagview::operator(): out of bounds");
+  arma_conform_check_bounds(((row >= n_elem) || (col > 0)),
+                            "spdiagview::operator(): out of bounds");
 
   return (const_cast<SpMat<eT>&>(m)).at(row + row_offset, row + col_offset);
 }
 
 template <typename eT>
 inline eT spdiagview<eT>::operator()(const uword row, const uword col) const {
-  arma_debug_check_bounds(((row >= n_elem) || (col > 0)),
-                          "spdiagview::operator(): out of bounds");
+  arma_conform_check_bounds(((row >= n_elem) || (col > 0)),
+                            "spdiagview::operator(): out of bounds");
 
   return m.at(row + row_offset, row + col_offset);
 }
 
 template <typename eT>
 inline void spdiagview<eT>::replace(const eT old_val, const eT new_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if (old_val == eT(0)) {
-    arma_debug_warn_level(1,
-                          "spdiagview::replace(): replacement not done, as old_val = 0");
+    arma_warn(1, "spdiagview::replace(): replacement not done, as old_val = 0");
   } else {
     Mat<eT> tmp(*this);
 
@@ -701,7 +700,7 @@ inline void spdiagview<eT>::replace(const eT old_val, const eT new_val) {
 
 template <typename eT>
 inline void spdiagview<eT>::clean(const typename get_pod_type<eT>::result threshold) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   Mat<eT> tmp(*this);
 
@@ -712,7 +711,7 @@ inline void spdiagview<eT>::clean(const typename get_pod_type<eT>::result thresh
 
 template <typename eT>
 inline void spdiagview<eT>::clamp(const eT min_val, const eT max_val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT> tmp(*this);
 
@@ -723,7 +722,7 @@ inline void spdiagview<eT>::clamp(const eT min_val, const eT max_val) {
 
 template <typename eT>
 inline void spdiagview<eT>::fill(const eT val) {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   if ((row_offset == 0) && (col_offset == 0) && (m.sync_state != 1)) {
     if (val == eT(0)) {
@@ -786,41 +785,49 @@ inline void spdiagview<eT>::fill(const eT val) {
 
 template <typename eT>
 inline void spdiagview<eT>::zeros() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   (*this).fill(eT(0));
 }
 
 template <typename eT>
 inline void spdiagview<eT>::ones() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   (*this).fill(eT(1));
 }
 
 template <typename eT>
 inline void spdiagview<eT>::randu() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT>& x = const_cast<SpMat<eT>&>(m);
 
   const uword local_n_elem = n_elem;
 
+  Col<eT> tmp(local_n_elem, arma_nozeros_indicator());
+
+  tmp.randu();
+
   for (uword i = 0; i < local_n_elem; ++i) {
-    x.at(i + row_offset, i + col_offset) = eT(arma_rng::randu<eT>());
+    x.at(i + row_offset, i + col_offset) = tmp[i];
   }
 }
 
 template <typename eT>
 inline void spdiagview<eT>::randn() {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
 
   SpMat<eT>& x = const_cast<SpMat<eT>&>(m);
 
   const uword local_n_elem = n_elem;
 
+  Col<eT> tmp(local_n_elem, arma_nozeros_indicator());
+
+  tmp.randn();
+
   for (uword i = 0; i < local_n_elem; ++i) {
-    x.at(i + row_offset, i + col_offset) = eT(arma_rng::randn<eT>());
+    x.at(i + row_offset, i + col_offset) = tmp[i];
   }
 }
 
